//
//  UserProfileFanTalkCheersItemView.swift
//  SodaLive
//
//  Created by klaus on 2023/08/11.
//

import SwiftUI
import Kingfisher

struct UserProfileFanTalkCheersItemView: View {
    
    let userId: Int
    let cheer: GetCheersResponseItem
    let writeCheerReply: (String) -> Void
    let modifyCheer: (Int, String) -> Void
    let reportPopup: (Int) -> Void
    
    @State var replyContent: String = ""
    @State var isShowInputReply = false
    
    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            HStack(alignment: .top, spacing: 6.7) {
                KFImage(URL(string: cheer.profileUrl))
                    .cancelOnDisappear(true)
                    .downsampling(size: CGSize(width: 33.3, height: 33.3))
                    .resizable()
                    .frame(width: 33.3, height: 33.3)
                    .clipShape(Circle())
                
                VStack(alignment: .leading, spacing: 0) {
                    Text("\(cheer.nickname)")
                        .font(.custom(Font.medium.rawValue, size: 13.3))
                        .foregroundColor(Color(hex: "eeeeee"))
                    
                    Text("\(cheer.date)")
                        .font(.custom(Font.medium.rawValue, size: 10.7))
                        .foregroundColor(Color(hex: "525252"))
                        .padding(.top, 8.3)
                    
                    Text("\(cheer.content)")
                        .font(.custom(Font.medium.rawValue, size: 12))
                        .foregroundColor(Color(hex: "777777"))
                        .padding(.top, 13.3)
                    
                    if isShowInputReply {
                        HStack(spacing: 10) {
                            TextField("응원댓글에 답글을 남겨보세요!", text: $replyContent)
                                .autocapitalization(.none)
                                .disableAutocorrection(true)
                                .font(.custom(Font.medium.rawValue, size: 13.3))
                                .foregroundColor(Color(hex: "eeeeee"))
                                .padding(13.3)
                                .background(Color(hex: "232323"))
                                .accentColor(Color(hex: "9970ff"))
                                .keyboardType(.default)
                                .cornerRadius(10)
                                .overlay(
                                    RoundedRectangle(cornerRadius: 10)
                                        .strokeBorder(lineWidth: 1)
                                        .foregroundColor(Color(hex: "9970ff"))
                                )
                            
                            Text("등록")
                                .font(.custom(Font.bold.rawValue, size: 13.3))
                                .foregroundColor(Color(hex: "ffffff"))
                                .padding(13.3)
                                .background(Color(hex: "9970ff"))
                                .cornerRadius(6.7)
                                .onTapGesture {
                                    if cheer.replyList.count > 0 {
                                        modifyCheer(cheer.replyList[0].cheersId, replyContent)
                                    } else {
                                        writeCheerReply(replyContent)
                                    }
                                }
                        }
                        .padding(.top, 10)
                    } else {
                        if cheer.replyList.count <= 0 {
                            if userId == UserDefaults.int(forKey: .userId) {
                                Text("답글쓰기")
                                    .font(.custom(Font.medium.rawValue, size: 12))
                                    .foregroundColor(Color(hex: "9970ff"))
                                    .padding(.top, 18.3)
                                    .onTapGesture {
                                        isShowInputReply = true
                                    }
                            }
                        } else {
                            let reply = cheer.replyList[0]
                            VStack(alignment: .leading, spacing: 8.3) {
                                Text(reply.content)
                                    .font(.custom(Font.medium.rawValue, size: 12))
                                    .foregroundColor(Color(hex: "ffffff"))
                                    .frame(minWidth: 100)
                                    .padding(.horizontal, 6.7)
                                    .padding(.vertical, 6.7)
                                    .background(Color(hex: "9970ff").opacity(0.3))
                                    .cornerRadius(16.7)
                                    .padding(.top, 18.3)
                                
                                HStack(spacing: 6.7) {
                                    Text(reply.date)
                                        .font(.custom(Font.medium.rawValue, size: 10.7))
                                        .foregroundColor(Color(hex: "525252"))
                                    
                                    if userId == UserDefaults.int(forKey: .userId) {
                                        Text("답글 수정")
                                            .font(.custom(Font.medium.rawValue, size: 10.7))
                                            .foregroundColor(Color(hex: "9970ff"))
                                            .onTapGesture {
                                                self.replyContent = reply.content
                                                isShowInputReply = true
                                            }
                                    }
                                }
                            }
                        }
                    }
                }
                
                Spacer()
                
                Image("ic_seemore_vertical")
                    .onTapGesture { reportPopup(cheer.cheersId) }
            }
            
            Rectangle()
                .frame(height: 1)
                .foregroundColor(Color(hex: "909090").opacity(0.5))
                .padding(.top, 13.3)
        }
        .frame(width: screenSize().width - 26.7)
    }
}
